@@ -1,7 +1,7 @@
 """cubicweb-ctl plugin providing the mboximport command
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -34,15 +34,21 @@ class MBOXImportCommand(Command):
           'default': False,
           'help': 'ask confirmation to continue after an error.',
           }),
+        ("skip-sign",
+         {'short': 's', 'action' : 'store_true',
+          'default': False,
+          'help': 'skip email signature.',
+          }),
         )
 
     def run(self, args):
         """run the command with its specific arguments"""
-        appid = args.pop()
+        appid = args.pop(0)
         cnx = config_connect(appid, self.config)
         cnx.load_appobjects(cubes=None, subpath=('entities',))
         importer = MBOXImporter(cnx, verbose=True,
-                                interactive=self.config.interactive)
+                                interactive=self.config.interactive,
+                                skipsign=self.config.skip_sign)
         # set autocommit, add an option to control that if needed
         importer.autocommit_mode()
         try:
