@@ -1,7 +1,7 @@
 """import an mbox or a single email into an cubicweb application
 
 :organization: Logilab
-:copyright: 2007-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -36,14 +36,14 @@ def combinaison(list):
 class MBOXImporter(object):
     """import content of a Unix mailbox into cubicweb as Email (and related) objects"""
 
-    def __init__(self, cnx,
-                 verbose=False, interactive=False):
+    def __init__(self, cnx, verbose=False, interactive=False, skipsign=False):
         self.cnx = cnx
         self.schema = cnx.get_schema()
         self.req = cnx.request()
         self.execute = self.req.execute
         self._verbose = verbose
         self._interactive = interactive
+        self._skipsign = skipsign
         self.created = {}
         self.skipped = []
         self.error = []
@@ -166,6 +166,8 @@ class MBOXImporter(object):
         if main == 'text':
             encoding = u'UTF-8'
         elif contenttype == 'application/pgp-signature':
+            if self._skipsign:
+                return
             encoding = u'ascii'
             if isinstance(data, str):
                 data = unicode(data, encoding)
@@ -178,8 +180,6 @@ class MBOXImporter(object):
         if name or main != 'text' and contenttype != 'application/pgp-signature':
             # suppose if we have a name, this is an attachement else this is a
             # part/alternative
-            if not name and main != 'text':
-                print 'duh', main, sub
             name = name or u'no name'
             if isinstance(data, unicode):
                 data = data.encode('utf8')
