@@ -19,5 +19,6 @@ _afs.tag_subject_of(('*', 'generated_by', 'Email'), 'main', 'hidden')
 
 class EmailPartIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
     __select__ = is_instance('EmailPart')
+
     def parent_entity(self):
-        return self.entity.thread
+        return self.entity.email
