@@ -57,6 +57,8 @@ class EmailPrimaryView(primary.PrimaryView):
             content, mime = part.content, part.content_format
             if mime == 'text/html':
                 content = soup2xhtml(content, self._cw.encoding)
+            elif 'pgp-signature' in mime:
+                content = entity._cw_mtc_transform(content, mime, 'text/html', self._cw.encoding)
             elif mime != 'text/xhtml':
                 content = xml_escape(content)
                 if mime == 'text/plain':
